@@ -5,17 +5,32 @@ Created on Aug 14, 2020
 '''
 import rgs.mndrpy.Meander as Meander
 import rgs.mndrpy.Utility as ut
-#import rgs.mndrpy.Pairing as pg
+import rgs.mndrpy.Pairing as pg
 import rgs.mndrpy.DyckPaths as dp
 
 
 import numpy as np
 import itertools 
 import matplotlib.pyplot as plt
+from sympy.combinatorics.permutations import Permutation
 #from progress.bar import Bar
 
 
-def cyclesOfPerm(perm):
+'''
+I assume that permutation is coded as a list,
+ obtained as permutation of range(n), 
+'''
+
+
+def inversions(perm):
+    ''' 
+    calculates the number of inversions for permutation perm.
+    '''
+    p = Permutation(perm)
+    return p.inversions()
+    
+
+def get_cycles(perm):
     ''' calculates all cycles in the permutation perm. 
     For, example if the permutation is 102534, then return a list of 
     [01][2][354]. Currently, the order of cycles and the order inside cycles are NOT
@@ -37,9 +52,9 @@ def cyclesOfPerm(perm):
     return cycles
         
 def cycleLengths(perm):
-    '''caclullates cycle lengths for a permutation. returns them in 
+    '''calсulates cycle lengths for a permutation. returns them in 
     decreasing order (as a partition of the length of the permutation'''
-    cycles = cyclesOfPerm(perm)
+    cycles = get_cycles(perm)
     y = np.sort(list(map(len, cycles)))
     y = y[::-1]
     return y     
@@ -98,8 +113,29 @@ def random231perm(n):
     p = dp.pathTo231perm(path)
     return p   
 
+
+def prtn2perm(prtn):
+    '''
+    calculates a permutation from a non-crossing partition.
+    For example, if prtn = [[0], [1], [2, 9, 8, 7], [3, 5, 4], [6]]
+    then it is converted to a permutation 
+    [[2, 7, 8, 9], [3, 4, 5]] in cycle notation
+    or 
+    [0, 1, 7, 4, 5, 3, 6, 8, 9, 2] in the word notation. 
+    '''
+    N = 0
+    for part in prtn:
+        part.sort()
+        m = max(part)
+        if m > N:
+            N = m
     
-    
+    perm = [0] * (N + 1)
+    for part in prtn:
+        for i in range(len(part) - 1):
+            perm[part[i]] = part[i + 1]
+        perm[part[len(part) - 1]] = part[0]
+    return perm
 
     
 '''
@@ -140,12 +176,30 @@ def main():
     plt.plot(p,'*')
     plt.grid()
 
-    cycles = cyclesOfPerm(p)
+    cycles = get_cycles(p)
     print(cycles)
     print(cycleLengths(p))    
     
+    #rng = np.random.default_rng()
+    #perm = rng.permutation(10)
+    perm = [7,3,2,6,4,5,1,0]
+    perm = [1,2,5,4,3,7,6,0]
+    print(perm)
     
-
+    cycles = get_cycles(perm)
+    print(cycles)
+    print("inversions =", inversions(perm))
+    
+    prtn = [[0], [1], [2, 9, 8, 7], [3, 5, 4], [6]]
+    perm = prtn2perm(prtn)
+    print(perm)
+    
+    
+    path = dp.randomDyckPath(n)
+    dp.plotDyckPath(path)
+    print("Area = ", dp.area(path))
+    perm = prtn2perm(pg.prng2prtn(dp.path2prng(path)))
+    print("Inversions = ", inversions(perm))
     
     plt.show()
 
