@@ -202,8 +202,8 @@ def areaMeander(mndr):
     as its upper boundary and the reflected Dyck path for the lower
     pairing as its lower boundary. The size of the meander is subtracted
     for normalization, so the area of the standard meander system is 0'''
-    area = dp.areaDyckPath(pr.prng2path(mndr.uPairing))
-    area += dp.areaDyckPath(pr.prng2path(mndr.dPairing))
+    area = dp.area(pr.prng2path(mndr.uPairing))
+    area += dp.area(pr.prng2path(mndr.dPairing))
     #area += mndr.size()
     return area
          
