@@ -249,6 +249,43 @@ def prng2path(prng):
             path[i] = -1
     return path.astype(int);
 
+def prng2prtn(prng):
+    '''
+    Calculate a NC partition on n elements from an NC pairing on 2n elements
+    '''
+    prtn = []
+    N = len(prng.prng)
+    marked = [False] * N #those elements that have been already processed.
+    #initialization
+    for x in range(0,N,2):
+        if marked[x]:
+            continue
+        piece = []
+        counter = 0
+        while counter < 10000:
+            if counter == 9999:
+                print("Warning from prng2partition: the cycle was repeated 10,000 times")
+            piece.append(x)
+            marked[x] = True
+            y = prng.prng[x]
+            piece.append(y)
+            x = y - 1
+            if marked[x]:
+                break
+        prtn.append(piece)
+    #now reduce it by halving
+    prtn1 = []
+    for piece in prtn:
+        piece1 = []
+        for x in piece:
+            if x % 2 == 0:
+                piece1.append(x//2)
+        prtn1.append(piece1)
+                   
+    return prtn1
+                
+        
+    
      
 
 '''
@@ -256,7 +293,7 @@ For testing methods
 '''
 def main():
     
-    n = 4
+    n = 10
     seed = None    
     prng = randomPairing(n, seed)
     #prng = standardPairing(n)
@@ -272,6 +309,9 @@ def main():
     print(path)
     dp.plotDyckPath(path)
     
+    prtn = prng2prtn(prng)
+    print(prtn)
+    
    
     #newPrng = addCrossing(prng, 0, 1)
     #newPrng.draw()
