@@ -255,13 +255,25 @@ class OrderedTree(object):
     
 
     def draw(self, drawLabels = False, rootInCenter = False, block = False, 
-             calculateRepr = "No", ax = None):
+             calculateRepr = "No", ax = None, rotate = False):
         '''
-        Draws the tree
+        Draws the tree using graph.draw function. 
+            Parameters:
+            - drawLabels : if True, draws the labels, 
+            - rootInCenter: if True, tries to put the root node in center 
             - block: if block is true, then calling 
-            the draw function will stop execution of further commands. 
-            if block is false (default), then the execution continues but the calling function
-            should have plt.show() at the end. 
+                the draw function will stop execution of further commands. 
+                if block is false (default), then the execution continues 
+                but the calling function
+                should have plt.show() at the end. 
+            - calculateRepr -- passes this to the graph.draw, however the 
+                default representation puts the leaves on the circle and calculate the rubber
+                representation for other vertices. 
+            - ax if given, draws the tree in the specified axis. 
+            
+            Returns:
+             fig and ax handles
+                
         '''
         fixiki = self.leaves() #if we want a correct graphical representation
                             #the leaves should be arranged in a correct order
@@ -275,6 +287,11 @@ class OrderedTree(object):
             fixiki.append(self.root)
             self.graph.reprOnCircle(fixiki)
         self.graph.calcRubberRepr(fixiki)
+        if rotate:
+            for count, point in enumerate(self.graph.repr):
+                self.graph.repr[count][0] = - point[0] 
+                self.graph.repr[count][1] = - point[1] 
+        #print(self.graph.repr)
         fig1, ax1 = self.graph.draw(root = 0, calculateRepr = calculateRepr,
                 drawLabels = drawLabels, block = block, ax = ax)
         return fig1, ax1
@@ -445,13 +462,13 @@ def main():
     #print(rw)
     
     n = 10
-    seed = 12345
-    #seed = 0 #(random - changing from one execution to another)
+    #seed = 12345
+    seed = 0 #(random - changing from one execution to another)
 
     tr = randomTree(n, w, SEED = seed)
     #tr = randomBTree(n, SEED = seed) 
     print(tr)
-    tr.draw(drawLabels=True)
+    tr.draw(drawLabels = True)
 
     heights, sizes = tr.calcHeightsSizes(0)
     print("heights = " + str(heights))
@@ -462,6 +479,7 @@ def main():
     These are some drawings and calculations associated with Slim Trees
     '''
     
+    '''
     n = 400
     #n = 20
     seed = 12345
@@ -490,7 +508,7 @@ def main():
     tr = fromDyck(path)
     
     _, ax = tr.draw(drawLabels = True, block = False)  
-    
+    '''
     plt.show() 
     
     
