@@ -948,8 +948,10 @@ class PlanarGraph:
         A = np.array(self.repr)
         x = A[:, 0]
         y = A[:, 1]
-        ax.set_xlim(np.amin(x), np.amax(x))
-        ax.set_ylim(np.amin(y), np.amax(y))
+        size_x = np.amax(x) - np.amin(x)
+        size_y = np.amax(y) - np.amin(y)
+        ax.set_xlim(np.amin(x)-0.1*size_x, np.amax(x)+0.1*size_x)
+        ax.set_ylim(np.amin(y)-0.15*size_y, np.amax(y)+0.15*size_y)
         ax.set_xticks([])
         ax.set_yticks([])
 
@@ -961,9 +963,9 @@ class PlanarGraph:
                     ax.add_line(line)
                     
         if root >= 0:
-            circle = plt.Circle((x[root], y[root]), 0.01, color='g', clip_on=False)
+            circle = plt.Circle((x[root], y[root]), 0.01, color='r', clip_on=False)
             ax.add_artist(circle)
-            ax.scatter(x[root], y[root], marker = "X", color = 'g')
+            ax.scatter(x[root], y[root], marker = "X", color = 'r')
         else:
             circle = plt.Circle((x[self.root], y[self.root]), 0.01, color='g', clip_on=False)
             ax.add_artist(circle)
@@ -971,7 +973,11 @@ class PlanarGraph:
         if drawLabels:
             if len(self.labels) == 0: #use index of the vertex instead of label
                 for v in range(self.V):
-                    ax.text(x[v],y[v], str(v))
+                    if v == root: #this is for trees: root is treated differently
+                        tau = 0.02
+                        ax.text(x[v]+tau*size_x,y[v]-4*tau*size_y, str(v))
+                    else:
+                        ax.text(x[v]+tau*size_x,y[v]+tau*size_y, str(v))
             else:
                 for v in range(self.V):
                     ax.text(x[v],y[v], str(self.labels[v]))
