@@ -174,6 +174,7 @@ def cyclicShift(path):
     else:
         path = np.concatenate([path[pos:n], path[0:pos]])
         return path.astype(np.int64)   
+    
 
 def randomBridge(n, w, ITER = 10000, SEED = 0):
     ''' creates a random walk bridge that starts at 0, ends at -1 and have
@@ -199,7 +200,7 @@ def randomBridge(n, w, ITER = 10000, SEED = 0):
         count = count + 1
 
     if (count == ITER and mu != -1):
-        print("RandomLukasiewicz says: Could not find a path that would "
+        print("randomBridge says: Could not find a path that would "
                     + "end in -1 after " + str(ITER) + "iterations")
 
     #convert multinomial array X to a path
@@ -210,6 +211,45 @@ def randomBridge(n, w, ITER = 10000, SEED = 0):
     np.random.shuffle(path)
     return path
 
+def genRandomBridge(n, w, target, ITER = 10000, SEED = 0):
+    '''
+    creates a random walk bridge with n steps that starts at 0, ends at target 
+    = n-k and have
+    the distribution of steps w. (w_0 corresponds to step 0)
+    returns: the path of the bridge as a sequence of steps. 
+    
+    w should be a probability distribution, it will not be re-weighted.
+    '''
+    K = len(w);
+    ##pp = rescale(w)
+    #get a sample from multinomial distribution
+    count = 0
+    mu = 0
+    if (SEED != 0):
+        np.random.seed(SEED)
+    else:
+        np.random.seed()
+    while (mu != target and count < ITER):
+        #repeat until the required property of the path is 
+        #ensured or too many iteration are used. 
+        X = np.random.multinomial(n, w)
+        mu = 0
+        for i in range(K):
+            mu = mu + i * X[i]
+        count = count + 1
+
+    if (count == ITER and mu != target):
+        print("genRandomBridge says: Could not find a path that would "
+                    + "hit the target after " + str(ITER) + "iterations")
+
+    #convert multinomial array X to a path
+    path = np.array([]);
+    for i in range(K): 
+        path = np.concatenate([path, np.array([i] * X[i])])
+    #print(path)    
+    np.random.shuffle(path)
+    return path
+
     '''
      * generate a random L􏰀ukasiewicz path that have n steps, starts at
       (0,0)  and never goes below the horizontal line except at the 
