@@ -38,13 +38,29 @@ class Tiling(object):
     
         
     def flip(self, i, j): 
-        ''' flip tiles number i and number j and returns true, if possible
-        do nothing and returns false if not possible
-        not yet complete.'''
-        #TODO
+        ''' flip tiles number i and number j and returns true, if possible,
+        do nothing and returns false if not possible.
+        
+        Parameters
+        --------------
+        i, j: integers 
+            the indices of ribbons to flip
+        
+        Returns:
+            True if successful
+            False if impossible
+        '''
+        
         A = self.ribbons[i]
         B = self.ribbons[j] 
-        flag, A1, B1 = ut.flip(A, B)
+        #print(A)
+        #print(B)
+        flag, A1, B1 = A.flip(B)
+        #print(A1)
+        #print(B1)
+        if flag:
+            self.ribbons[i] = A1
+            self.ribbons[j] = B1
         return flag
           
         
@@ -120,6 +136,16 @@ class Tiling(object):
         return fig, ax
 
 
+def fromString(s):
+    '''
+    initializes a tiling from a string like the following
+    '(0,0), [1, 1]
+    (2,1), [1, 0]
+    (1,0), [1, 1]'
+     '''
+    #TODO
+    pass
+
 def standardAztec2(M):
     '''
     generate a standard tiling of an M-by-M Aztec Diamond by dominos
@@ -152,7 +178,8 @@ def standardT(n, M, N = None):
         
     ribbons = []
     #This should be changed. we need to add ribbons in standard order. 
-    levels, vertex2level = getHelpersRect(n, M, N)
+    levels, vertex2level = _getHelpersRect(n, M, N)
+    #print("vertex2level = ", vertex2level)
     for v, level in enumerate(vertex2level):
         position = levels[level].index(v)
         if level < M * n:
@@ -168,23 +195,58 @@ def standardT(n, M, N = None):
             y = level - x 
             ribbon = rb.Ribbon(x, y, [1] * (n - 1))
             ribbons.append(ribbon)
-    #for i in range(N):
-    #    for j in range(M):
-    #        ribbon = rb.Ribbon(i, j*n, [1] * (n - 1))
-    #        ribbons.append(ribbon)
     t = Tiling(ribbons)
     return t
 
-def randomT(n, M, N, ITER = 1000):
+def randomT(n, M, N, ITER = 10, seed = None):
     '''
     generate a random tiling of Mn - by - N rectangle (Mn - height,
     N - width)
     by using a version of Markov Chain algorithm with flips
+    
+    Parameters
+    ------------
+    n: integer
+        length of tile
+    M, N: integers
+        The region is Mn - by - N rectangle
+    ITER: integer
+        parameter that determines how long to run the algorithm
+        typically every tile is touched around ITER times
+    seed: integer
+        the seed of the random generator, for reproducibility,
+        default = None
+    
+    Returns
+    ------------
+    random ribbon tiling
+    
     '''
-    #TODO
-    pass
+    #There are some errors 
+    
+    if (seed != None):
+        np.random.seed(seed)
+    else:
+        np.random.seed()
+        
+    t = standardT(n, M, N)
+    V = len(t.ribbons)
+    #for v in range(V):
+    #    print(t.ribbons[v])
+    helpers = _getHelpersRect(n, M, N)
+    #print("Herlpers =", helpers)
+    for count in range(ITER):
+        for v in range(V):
+            #print("v = ", v)
+            flips = ut.findFlips(n, v, t, helpers)
+            if len(flips) > 0:
+                i = np.random.randint(len(flips))
+                w = flips[i]
+                #print("w = ", w)                
+                t.flip(v,w)
+    return t
 
-def getHelpersRect(n, M, N):
+def _getHelpersRect(n, M, N):
     '''
     create helper structures for a rectangle with number of rows M * N 
     and number of columns N
@@ -229,6 +291,9 @@ def getHelpersRect(n, M, N):
             ribbon = rb.Ribbon(i, j*n, [1] * (n - 1))
             ribbons.append(ribbon)
     st = Tiling(ribbons)
+    #print(len(ribbons))
+    #print("Auxiliary = ", st)
+    
     for ribbon in st.ribbons:
         l = ribbon.level()
         level_lengths[l] += 1
@@ -239,45 +304,7 @@ def getHelpersRect(n, M, N):
         levels.append(level)
         x = x + level_lengths[l]
     #print(levels)
-    #Now we want make a digraph
-    '''
-    for l in range(nlevels):
-        level = levels[l]
-        for i, v in enumerate(level): 
-            if l < (M - 1) * n: #lower levels
-                if l < n:
-                    w = levels[l + n][i + 1]
-                    digraph.add_edge(v, w)
-                else:
-                    if i + 1 < level_lengths[l + n]:
-                        w = levels[l + n][i + 1]
-                        digraph.add_edge(v, w)
-                    if i < level_lengths[l - n]:
-                        #print("v = ", v, "i = ", i, "l = ", l)
-                        w = levels[l - n][i]
-                        digraph.add_edge(v, w)
-            elif l < M * n: #middle level
-                    if i < level_lengths[l + n]:
-                        w = levels[l + n][i]
-                        #print("v = ", v, "i = ", i, "l = ", l, "w = ", w)
-                        digraph.add_edge(v, w)
-                    if i < level_lengths[l - n]:
-                        #print("v = ", v, "i = ", i, "l = ", l)
-                        w = levels[l - n][i]
-                        digraph.add_edge(v, w)
-            else: #upper levels
-                if l >= nlevels - n:
-                    w = levels[l - n][i + 1]
-                    digraph.add_edge(v, w)
-                else:
-                    if i + 1 < level_lengths[l - n]:
-                        w = levels[l - n][i + 1]
-                        digraph.add_edge(v, w)
-                    if i < level_lengths[l + n]:
-                        #print("v = ", v, "i = ", i, "l = ", l)
-                        w = levels[l + n][i]
-                        digraph.add_edge(v, w)   
-    '''
+
     vertex2level = [-1] * M * N                    
     for l in range(nlevels):
         for i in range(level_lengths[l]):
@@ -285,55 +312,8 @@ def getHelpersRect(n, M, N):
          
     return levels, vertex2level
 
-def findFlips(n, v, tiling, helpers):
-    '''
-    find all flips that involve the ribbon v
-    
-    Parameters
-    -----------
-    n: integer
-        ribbon length
-    v: integer 
-        the index of the tile
-    tiling: Tiling
-        the tiling in which we looking for flips. 
-    helpers: a tuple (levels, vertex2level)
-        represent the structure of the tiling
-        levels is a list of integer lists. Every list is the 
-              collection of vertices in this level
-        vertex2level is the map from the vertex to levels
-             for example [0, 1, 2, 2, ...] means that the
-             vertex 0 is in the 0 level, vertex 1 is in the 1 level
-             vertices 2 and 3 are in the 2-nd level and so on.
-        For a rectangle this structure is calculated by getHelpersRect
-        function
-        
-    
-    Returns:
-    list of possible tuples (w, C, D) where w is the index of the tile that 
-    can be flipped with v, and (C, D) is the pair of flipped ribbons
-    so that C can be put at index v and D at index w. 
-    The list can be empty 
-    '''
-    (levels, vertex2level) = helpers
-    flips = []
-    A = tiling.ribbons[v]
-    level = vertex2level[v]
-    a = max([0, level - n + 1])
-    b = min([len(levels),level + n])
-    for i in range(a, b):
-        if i == level:
-            continue
-        else:
-            for w in levels[i]:
-                B = tiling.ribbons[w]
-                flag, C, D = ut.flip(A, B)
-                if flag:
-                    flips.append((w, C, D))
-    return flips
 
-
-def getHelpers(n, M):
+def _getHelpers(n, M):
     '''
     create a generic digraph of a tiling for a square
     with side M * n and other helper structures
@@ -451,7 +431,7 @@ def buildFromTilingSeq(seq, n, M):
     
     Returns: a tiling 
     '''
-    (_, levels, _, vertex2level) = getHelpers(n,M)
+    (_, levels, _, vertex2level) = _getHelpers(n,M)
     
     ribbons = []
     
@@ -508,7 +488,7 @@ def makeRandomTS(n, M):
     
     '''
     
-    (digraph, _, _, vertex2level) = getHelpers(n,M)
+    (digraph, _, _, vertex2level) = _getHelpers(n,M)
     #initiate a sequence
     rev_digraph = digraph.reverse()
     ts = list(np.random.permutation(n))
@@ -556,7 +536,7 @@ def makeRandomTS(n, M):
         #print("ts = ", ts)                                         
     return ts
 
-def getHelpersAztec2(M):
+def _getHelpersAztec2(M):
     '''
     create a generic digraph of a domino tiling for an Aztec
     Diamond with side M and other helper structures.
@@ -675,7 +655,7 @@ def buildAztec2FromTilingSeq(seq, M):
     Returns: a tiling 
     '''
     #TODO (smth not OK)
-    (_, levels, _, vertex2level) = getHelpersAztec2(M)
+    (_, levels, _, vertex2level) = _getHelpersAztec2(M)
     
     ribbons = []
     n = 2 #we are working with dominos
@@ -731,7 +711,7 @@ def makeRandomTS_Aztec2(M):
     
     '''
     #the specific 
-    (digraph, _, _, vertex2level) = getHelpersAztec2(M)
+    (digraph, _, _, vertex2level) = _getHelpersAztec2(M)
     #initiate a sequence
     rev_digraph = digraph.reverse()
     ts = list(range(M))
@@ -800,27 +780,65 @@ def main():
                 colorByLength = False, colormap = "prism")
     '''
     
+    
+    A = rb.Ribbon(0, 0, [0, 0, 0, 1, 1, 0, 0, 1])
+    B = rb.Ribbon(2, 1, [1, 1, 0, 0, 1, 0, 0, 0])
+    
+    tiling = Tiling([A, B]) 
+    print(tiling)
+
+    '''
+    (0,0), [1, 1]
+    (2,1), [1, 0]
+    (1,0), [1, 1]
+    (1,3), [1, 1]
+    (2,0), [0, 1]
+    (2,4), [1, 0]
+    (0,3), [1, 1]
+    (2,3), [0, 1]
+     '''   
+    
     '''testing building a standard tiling'''
     
     n = 3
     M = 2
     N = 3
-    t = standardT(n, M, N)
-    print(t)
+    #t = standardT(n, M, N)
     #print(t)
-    _, ax2 = plt.subplots()
-    t.draw(M * n, N, ax = ax2)
+    _, ax2 = plt.subplots(1,1)
+    #t.draw(M * n, N, ax = ax2)
     
     #let us look at some helper structures
-    levels, vertex2level = getHelpersRect(n, M, N)
+    '''
+    levels, vertex2level = _getHelpersRect(n, M, N)
     print(levels)
     print(vertex2level)
+    '''
     
-    v = 1
-    flips = findFlips(n, v, t, (levels, vertex2level))
-    for flip in flips:
-        print("w = ", flip[0], "C = ", flip[1], "D = ", flip[2])
+    '''testing building a random tiling'''
+    n = 5
+    M = 1
+    N = 30
+    helpers = _getHelpersRect(n, M, N)
+    t = randomT(n, M, N, ITER = 100)
+    #print(t)
+    t.draw(M * n, N, ax = ax2)
+    flips = ut.findFlips(n, 4, t, helpers)
     
+    A = t.ribbons[4]
+    print("A = ", A)
+    print(flips)
+    #B = t.ribbons[5]
+    #(flag, C, D)= A.flip(B)
+    #print(flag)
+    #_, ax = A.draw()
+    #B.draw(ax = ax)
+    #print(flips)
+    
+    
+    
+    #t.flip(4,5)
+    #t.draw(M * n, N, ax = ax2[1])
     
     '''
     Testing Yinsong's algorithm for the random generation of a rectangle tiling
